@@ -45,8 +45,8 @@ extern "C" {
 #define LIBIDL_GEN_VERSION(a,b,c)	(((a) << 16) + ((b) << 8) + (c))
 #define LIBIDL_MAJOR_VERSION		0
 #define LIBIDL_MINOR_VERSION		8
-#define LIBIDL_MICRO_VERSION		8
-#define LIBIDL_VERSION_CODE		LIBIDL_GEN_VERSION(0,8,8)
+#define LIBIDL_MICRO_VERSION		10
+#define LIBIDL_VERSION_CODE		LIBIDL_GEN_VERSION(0,8,10)
 
 /* miscellaneous constants */
 #define IDL_SUCCESS			0
@@ -101,7 +101,7 @@ extern "C" {
 #define IDL_CHECK_CAST(tree, thetype, name)			\
 	(IDL_check_type_cast(tree, thetype,			\
 			    __FILE__, __LINE__,			\
-			    G_GNUC_PRETTY_FUNCTION)->u.name)
+			    G_STRFUNC)->u.name)
 
 /* GLib 2.0 requires 64-bit types */
 #define IDL_LL		"ll"
